use std::{fs, path::Path};

#[derive(sqlx::FromRow, Debug)]
pub struct Sheet {
    pub id: i32,
    pub name: String,
    // #[sqlx(from = "String")]
    pub path: String,
    // #[sqlx(from = "i64")]
    pub file_size: i32,
    pub file_hash: String,
}

#[derive(sqlx::FromRow)]
pub struct Composer {
    pub id: i32,
    pub name: String,
}

impl Sheet {
    pub fn validate_path(&self, path: impl AsRef<Path>) -> std::io::Result<bool> {
        // First compare file size since it is faster than hashing
        let file_size = fs::metadata(path.as_ref())?.len();
        if file_size as i32 == self.file_size {
            let file_content = fs::read(path.as_ref())?;
            let file_hash = blake3::hash(&file_content);
            if file_hash.to_string() == self.file_hash {
                return Ok(true);
            }
        }

        Ok(false)
    }
}
